/*
layout.css -- css stylesheet used on www.gnu.org

Copyright (C) 2006, 2007, 2008, 2009 Free Software Foundation

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.
*/
@media print {
    body {
        background-color: black; /*:-P*/
    }
}
/* NOTE: Changes to this file will affect the entire site, often in
unexpected ways. Please mail patches to www-discuss@gnu.org rather
than commit changes directly. */

html, body{
        padding: 0;
        margin: 0;
        color: #35382a;
}

/* the urgent div should be enabled when we have something urgent to
appear on every page - these typically come from johns, peterb or rms
at the fsf */

#urgent{

background-color:#ff3;
line-height: 3em;
font-size: 0.9em;
text-align: center;
border-bottom: 5px solid #333;
 }

#urgent a, #urgent a:visited{
color: blue; text-decoration: underline !important;
}

#urgent a:hover{ background-color: red; }

  body{
  font-family: sans-serif;
  }

  #wrapper{
  margin: 0;
  background-color: transparent;
  padding: 0em;
  position: relative;
  }

a:hover{ color: red; }


.inner { max-width: 58em; margin: 0 auto 0; position: relative; min-width: 902px; }

.inner{ padding-left: 10px; padding-right: 10px; }

#logo{background:url(/graphics/topbanner.png) no-repeat;border:0;margin:0em;padding:0;}

#logo a { display:block;text-decoration:none;overflow:hidden;border:0;margin:0;padding:0;padding-top:101px;height:0px !important;width:550px;cursor:pointer;}

#header{ position: relative; height: 101px;}

#fsf-logo{ position: absolute; top: 0; right: 25px; }

#links{ display: none !important; }

#links{ position: absolute; top: 5px; right: 1em; border-left: 1px
 solid #333; padding-left: 1em;height: 90px; overflow: hidden; }

#links ul{ padding-left: 1em; padding-top: 1em; }

#links li { line-height: 1.6em; font-size: 0.9em; }

#content { background-color: #fff;  padding-bottom: 1.8em;  margin-top: 0.5em;  }

#navigation{ background-color: #bd0000; border-bottom: 5px solid #333;}

#navigation ul{ line-height: 3em; font-size: 0.8em; }

#navigation li{display: inline; margin: 0 0px; padding: 0.5em 1em 0.5em 1em; }

#navigation li a {color: white; text-decoration: none; font-weight: bold; line-height: 3em;}

#navigation li a:hover{ background-color: #bd0000;  }

#navigation li:hover a{ color: yellow; }

#joinfsftab a{color: yellow !important}

#content h2 {
 background-color: #3465a4; color: white; font-size: 1.2em;
 margin-bottom: 0.3em; font-weight:bold; text-align: center; line-height: 1.6em; }

#content h3, #content h4, #content h5, #content h6 {line-height: 1.5em;}

#content h3{ font-size: 1.1em; }

#content h4{ font-size: 1.0em; }

#content h5{ font-size: 0.9em; }

#content h6{ font-size: 0.8em; }

.caption{ color: #3465a4; font-size: 1.5em !important; margin:0; }

.netscape4{
  display: none !important;
  height: 0;
}

/* CSS classes for doing things like two columns */

.rowOfBoxes {
  clear: both;
}

.quarter, .oneThird, .half, .twoThirds, .fullWidth {
  margin: 1em 0;
  float: left;
  border-left: 1px solid rgb(204,204,204);
}

.quarter {
  width: 21%;
  padding: 0 1.9%;
}

.oneThird {
  width: 28%;
  padding: 0 1.9%;
}

.half {
  text-align: left;
  width: 46%;
  padding: 0 1.9%;
}

.half h3{padding: 0; margin: 0; font-size: 1.8em;}

.twoThirds {
  text-align: left;
  width: 63%;
  padding: 0 1.9%;
}

.fullWidth {
  text-align: left;
  width: 96%;
  padding: 0 1.2em;
  border-left: none;
}

.filler {  /* use with an empty <p> element to add padding to the end of a text box */
  border: 1px solid white;
}

.noBorderOnLeft {
  border-left: none;
}

.dividingBorderAbove {
  border-top: 1px solid rgb(204,204,204);
}

#translations{ background-color: #fff; 
 padding: 1em; padding-top: 0; color: #000;   }

#translations h3, #translations h4{ font-size: 1em; font-weight: bold; margin-bottom: 0.5em; padding: 0; }

#translations li{direction: ltr; display: inline-block; line-height: 1.7em; }

#translations  a{ color: blue !important; }

#footer { background-color: #fff; border-top: 5px solid #444; padding:1em; color: #000; margin-top: 1em; }

#footer a{ color: blue; }

#footer p{ margin-bottom: 0.7em; }

#footer, #translations { font-size: 0.9em; }

.announcement{ font-size: 1.1em; font-weight: bold; padding-left: 1em; margin-left: 1em; border-left: 1em solid #eee; margin-bottom: 1em; }

img{ border: 0; }

#rms-image{
width: 200px;
height: 219px;
float: right;
margin-left: 1em; margin-bottom: 1em;
border: 1px solid #ddd;
background-image: url('/graphics/rms2005chrys.jpg');
}

.lyrics{background-color: whitesmoke; font-style: italic; width: 25em; padding: 2em; border: 2px solid #e5e5e5; margin-left: 2em;}

  #gplv3-dogear{
    position: absolute;
    top: -1px;
    left: -1px;
 }

  #gplv3-dogear h3{margin: 0;}

  #gplv3-dogear a{
    background-image: url('/graphics/dogear.png');
    border: 0;
    display: block;
    text-decoration: none;
    overflow: hidden;
    height: 0px !important;
    width: 64px;
    padding: 0;
    padding-top: 64px;
    cursor: pointer;

 }

hr { display: none; }

.nocenter{ text-align: left; }

/* Licensing */
/* This is for licenses/gpl-faq.html. */

table#gpl-compat-matrix { border-collapse: collapse; }

table#gpl-compat-matrix td, th.gpl-matrix-border {
    text-align: center; border: 1px solid black; margin: 0;
    padding: .3em; }

th.gpl-matrix-license { text-align: right; }

tr.gpl-matrix-use-type { border-top: 2px solid black; }

table#gpl-compat-matrix td.ok { background-color: #ccffcc; }
table#gpl-compat-matrix td.mok { background-color: #e4ffcc; }
table#gpl-compat-matrix td.nok { background-color: #dddddd; }

#print-this-article p{ text-align: center; }


#content ul, #fsf-campaigns ul{ list-style: square; margin-left: 1.4em; list-style-image:url(/graphics/bullet.gif);  }

#content ol{ list-style: decimal; margin-left: 1.9em; }

#content li, #fsf-campaigns li, #content dt, #content dd, #content p{ padding-bottom: 1em; line-height: 1.5em; }

#content dd{ margin-bottom: 2em }

#content dt{ font-weight: bold;  }

pre {
padding-left: 1.5em;
padding-right: 1.5em;
margin-top: 1em;
margin-bottom: 1em;
font-size: 0.9em;
display: block;
background-color: #eeeeee;
color: #000000;
font-family: monospace;
}

#bottom-links{ background-color: #fff; font-size: 0.8em;}

#bottom-links li{ display: inline; margin-right: 1em; line-height: 2em; }

#backtotop{ padding-bottom: 1em; background-color: #fff; }

#backtotop p{ text-align: right; }

strong, b{ font-weight: bold; }

em, i, var{ font-style: italic; }

blockquote{ margin: 1em; font-style: italic; }

code, kbd, samp, tt{ font-family: monospace; }

#toplinks{font-size: 80%; padding: 4px; z-index: 999; top: 0; left: 0; }

#toplinks a{ font-weight: bold; color: #888; } 

#toplinks a:hover, #toplinks a:active{color: blue;}

.center{ text-align:center; }

.big{ font-size: 130%; padding-top: 0.7em; }

.inline-list li { display: inline }

#searcher{ position: absolute; top: 0; right: 1em; line-height: 3em; color: white; text-transform: uppercase; font-weight: bold; background-color: maroon; padding-left: 1em; padding-right: 1em;}

#searcher, #searcher input{ font-size: 0.8em; }

.highlight{background-color: #ff6;}

#takeactionhomepage{background-color: #c2e155; color: black; margin-bottom: 0.5em; font-size: 90%;}

#takeactionhomepage h1{text-align: center !important; border: 0 !important; color: black; font-size: 2em !important; padding-top: 0.2em;}

#takeactionhomepage ul{list-style: none !important; text-align: center; margin: 0 !important; padding: 0 !important; margin-top: 1em !important;}

#takeactionhomepage li{line-height: 1.3em; list-style: none !important;}

#fssbox {text-align: center; position: absolute; top: 0; right: 0; height: 101px; width: 310px; font-size: 80%;}

#fssbox h1, #fssbox p{ line-height: 30px;}

#content h2 a{color: yellow !important;}

acronym, abbr {border-bottom: 1px dotted #111;}

.pad {margin-bottom: 1em;}

#fpnav ul{list-style: none; margin: 0 !important; padding: 0 !important;}

#fpnav li{display: block; text-align: left; margin-right: 1em; font-size: 0.9em;}

#fpnav li a{display: block; padding-top: 6px; padding-bottom: 6px;}

#fpnav li a:hover{text-decoration: none; background-color: yellow;}

.pad td{padding-left: 1em; padding-right: 1em;}

.pad td:first-child{padding-left: 0;}

.pad td:last-child{padding-right: 0;}

.imgright{ float: right; margin: 12px; }

.imgleft { float: left; margin: 12px; }

.c { text-align: center; }

.listing,
.stx table {
    /* The default table for document listings. Contains name, document types, modification times etc in a file-browser-like fashion */
    border-collapse: collapse;
    border-left: 1px solid #666666;
    border-bottom: 1px solid #666666;
    margin: 1em 0em 1em 0em;
}
.listing th,
.stx table th {
    background: DarkRed;
    color: white;
    font-weight: bold !important;
    border-top: 1px solid #666666;
    border-bottom: 1px solid #666666;
    border-right: 1px solid #666666;
    font-weight: normal;
    padding: 1em;
    text-transform: ;
}

.listing td a { display: block; }

.listing .top {
    border-top: 1px solid #666666;
    text-align: right ! important;
    padding: 0em 0em 1em 0em;
}
.listing .odd {
    /*every second line should be shaded */
    background-color: transparent;
}
.listing .even {
    background-color: #ededed;
}
.listing .listingCheckbox {
    text-align: center;
}
.listing td,
.stx table td {
    border-right: 1px solid #666666;
    padding: 1em;
    text-align: center;
                line-height: 1.3em
}
.listing a:hover {
    text-decoration: underline;
}
.listing img {
    vertical-align: middle;
}

.listing { width: 100%; }
