package CSS::Croco::Term::Number;

use utf8;
use strict;
use warnings;

our @ISA = qw(CSS::Croco::Term);

1;

__END__

=head1 NAME

CSS::Croco::Term::Number - Number value of property

=head1 DESCRIPTION

Number handles various numeric properties: 1, 2px, 30% etc. Subclass of L<CSS::Croco::Term::Number>

=head1 METHODS

=head2 get

Returns value of property

=head1 BUGS

=head1 NOTES

=head1 AUTHOR

Andrey Kostenko (), <andrey@kostenko.name>

=head1 COMPANY

Rambler Internet Holding

=head1 CREATED

06.11.2009 20:31:01 MSK

=cut

