package CSS::Croco::Selector;

1;

=head1 NAME

CSS::Croco::Selector - Selector object

=head1 DESCRIPTION

A full description of the module and its features.
May include numerous subsections (i.e. =head2, =head3, etc.)


=head1 METHODS


=head2 is_case_sensitive

=head2 to_string

=head2 name



=head1 AUTHOR

Andrey Kostenko  (andrey@kostenko.name)


=head1 LICENCE AND COPYRIGHT

Copyright (c) 2009  (andrey@kostenko.name). All rights reserved.

Followed by whatever licence you wish to release it under.
For Perl code that is often just:

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See perldoc perlartistic.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

=cut



