package CSS::Croco::Term::String;

use utf8;
use strict;
use warnings;

our @ISA = "CSS::Croco::Term";

__END__

=head1 NAME

CSS::Croco::Term::String - String terms

=head1 DESCRIPTION

Handles strings like C<"Times New Roman">

=head1 BUGS

=head1 NOTES

=head1 AUTHOR

Andrey Kostenko (), <andrey@kostenko.name>

=head1 COMPANY

Rambler Internet Holding

=head1 CREATED

06.11.2009 22:20:55 MSK

=cut

use strict;
use warnings;



