package CSS::Croco::Term::Hash;

use utf8;
use strict;
use warnings;

our @ISA = qw(CSS::Croco::Term);

1;

__END__

=head1 NAME

CSS::Croco::Term::Hash - hash-color values

=head1 DESCRIPTION

Handles values like #fffff, #f00 etc..

=head1 BUGS

=head1 NOTES

=head1 AUTHOR

Andrey Kostenko (), <andrey@kostenko.name>

=head1 COMPANY

Rambler Internet Holding

=head1 CREATED

06.11.2009 20:34:59 MSK

=cut

