#column-content {
  width : 100%;
  float : right;
  margin : 0 0 0.59999999999999998em -12.199999999999999em;
  padding : 0
}

#content {
  margin : 2.7999999999999998em 0 0 12.199999999999999em;
  padding : 0 1em 1em 1em;
  position : relative;
  z-index : 2
}

#column-one {
  padding-top : 160px
}

#content {
  background : white;
  color : black;
  border : 1px solid #aaa;
  border-right : none;
  line-height : 1.5em
}

body {
  font : x-small sans-serif;
  background : #f9f9f9 url(headbg.jpg) 0 0 no-repeat;
  color : black;
  margin : 0;
  padding : 0
}

#globalWrapper {
  font-size : 127%;
  width : 100%;
  margin : 0;
  padding : 0
}

table {
  font-size : 100%;
  color : black;
  background-color : white
}

fieldset table {
  background : none
}

a {
  text-decoration : none;
  color : #002bb8;
  background : none
}

a:visited {
  color : #5a3696
}

a:active {
  color : #faa700
}

a:hover {
  text-decoration : underline
}

a.stub {
  color : #772233
}

a.new, #p-personal a.new {
  color : #ba0000
}

a.new:visited, #p-personal a.new:visited {
  color : #a55858
}

img {
  border : none;
  vertical-align : middle
}

p {
  margin : 0.40000000000000002em 0 0.5em 0;
  line-height : 1.5em
}

p img {
  margin : 0
}

hr {
  height : 1px;
  color : #aaa;
  background-color : #aaa;
  border : 0;
  margin : 0.20000000000000001em 0 0.20000000000000001em 0
}

h1, h2, h3, h4, h5, h6 {
  color : black;
  background : none;
  font-weight : normal;
  margin : 0;
  padding-top : 0.5em;
  padding-bottom : 0.17000000000000001em;
  border-bottom : 1px solid #aaa
}

h1 {
  font-size : 188%
}

h1.editsection {
  font-size : 53%
}

h2 {
  font-size : 150%
}

h2.editsection {
  font-size : 67%
}

h3, h4, h5, h6 {
  border-bottom : none;
  font-weight : bold
}

h3 {
  font-size : 132%
}

h3.editsection {
  font-size : 76%;
  font-weight : normal
}

h4 {
  font-size : 116%
}

h4.editsection {
  font-size : 86%;
  font-weight : normal
}

h5 {
  font-size : 100%
}

h5.editsection {
  font-weight : normal
}

h6 {
  font-size : 80%
}

h6.editsection {
  font-size : 125%;
  font-weight : normal
}

ul {
  line-height : 1.5em;
  list-style-type : square;
  margin : 0.29999999999999999em 0 0 1.5em;
  padding : 0;
  list-style-image : url(bullet.gif)
}

ol {
  line-height : 1.5em;
  margin : 0.29999999999999999em 0 0 3.2000000000000002em;
  padding : 0;
  list-style-image : none
}

li {
  margin-bottom : 0.10000000000000001em
}

dt {
  font-weight : bold;
  margin-bottom : 0.10000000000000001em
}

dl {
  margin-top : 0.20000000000000001em;
  margin-bottom : 0.5em
}

dd {
  line-height : 1.5em;
  margin-left : 2em;
  margin-bottom : 0.10000000000000001em
}

fieldset {
  border : 1px solid #2f6fab;
  margin : 1em 0 1em 0;
  padding : 0 1em 1em;
  line-height : 1.5em
}

fieldset.nested {
  margin : 0 0 0.5em 0;
  padding : 0 0.5em 0.5em
}

legend {
  padding : 0.5em;
  font-size : 95%
}

form {
  border : none;
  margin : 0
}

textarea {
  width : 100%;
  padding : 0.10000000000000001em
}

input.historysubmit {
  padding : 0 0.29999999999999999em 0.29999999999999999em 0.29999999999999999em !important;
  font-size : 94%;
  cursor : pointer;
  height : 1.7em !important;
  margin-left : 1.6000000000000001em
}

select {
  vertical-align : top
}

abbr, acronym, .explain {
  border-bottom : 1px dotted black;
  color : black;
  background : none;
  cursor : help
}

q {
  font-family : Times, "Times New Roman", serif;
  font-style : italic
}

code {
  background-color : #f9f9f9
}

pre {
  padding : 1em;
  border : 1px dashed #2f6fab;
  color : black;
  background-color : #f9f9f9;
  line-height : 1.1000000000000001em
}

#siteSub {
  display : none
}

#jump-to-nav {
  display : none
}

#contentSub, #contentSub2 {
  font-size : 84%;
  line-height : 1.2em;
  margin : 0 0 1.3999999999999999em 1em;
  color : #7d7d7d;
  width : auto
}

span.subpages {
  display : block
}

#bodyContent h1, #bodyContent h2 {
  margin-bottom : 0.59999999999999998em
}

#bodyContent h3, #bodyContent h4, #bodyContent h5 {
  margin-bottom : 0.29999999999999999em
}

#firstHeading {
  margin-bottom : 0.10000000000000001em;
  line-height : 1.2em;
  padding-bottom : 0
}

.usermessage {
  background-color : #ffce7b;
  border : 1px solid #ffa500;
  color : black;
  font-weight : bold;
  margin : 2em 0 1em;
  padding : 0.5em 1em;
  vertical-align : middle
}

#siteNotice {
  text-align : center;
  font-size : 95%;
  padding : 0 0.90000000000000002em
}

#siteNotice p {
  margin : 0;
  padding : 0
}

.catlinks {
  border : 1px solid #aaa;
  background-color : #f9f9f9;
  padding : 5px;
  margin-top : 1em;
  clear : both
}

.documentDescription {
  font-weight : bold;
  display : block;
  margin : 1em 0;
  line-height : 1.5em
}

.documentByLine {
  text-align : right;
  font-size : 90%;
  clear : both;
  font-weight : normal;
  color : #76797c
}

.center {
  width : 100%;
  text-align : center
}

*.center * {
  margin-left : auto;
  margin-right : auto
}

.small, .small * {
  font-size : 94%
}

table.small {
  font-size : 100%
}

#toc, .toc, .mw-warning {
  border : 1px solid #aaa;
  background-color : #f9f9f9;
  padding : 5px;
  font-size : 95%
}

#toc h2, .toc h2 {
  display : inline;
  border : none;
  padding : 0;
  font-size : 100%;
  font-weight : bold
}

#toc#toctitle, .toc#toctitle, #toc.toctitle, .toc.toctitle {
  text-align : center
}

#toc ul, .toc ul {
  list-style-type : none;
  list-style-image : none;
  margin-left : 0;
  padding-left : 0;
  text-align : left
}

#toc ul ul, .toc ul ul {
  margin : 0 0 0 2em
}

#toc.toctoggle, .toc.toctoggle {
  font-size : 94%
}

.mw-warning {
  margin-left : 50px;
  margin-right : 50px;
  text-align : center
}

div.floatright, table.floatright {
  clear : right;
  float : right;
  position : relative;
  margin : 0 0 0.5em 0.5em;
  border : 0
}

div.floatright p {
  font-style : italic
}

div.floatleft, table.floatleft {
  float : left;
  clear : left;
  position : relative;
  margin : 0 0.5em 0.5em 0;
  border : 0
}

div.floatleft p {
  font-style : italic
}

div.thumb {
  margin-bottom : 0.5em;
  border-style : solid;
  border-color : white;
  width : auto
}

div.thumbinner {
  border : 1px solid #ccc;
  padding : 3px !important;
  background-color : #f9f9f9;
  font-size : 94%;
  text-align : center;
  overflow : hidden
}

html.thumbimage {
  border : 1px solid #ccc
}

html.thumbcaption {
  border : none;
  text-align : left;
  line-height : 1.3999999999999999em;
  padding : 3px !important;
  font-size : 94%
}

div.magnify {
  float : right;
  border : none !important;
  background : none !important
}

div.magnify a, div.magnify img {
  display : block;
  border : none !important;
  background : none !important
}

div.tright {
  clear : right;
  float : right;
  border-width : 0.5em 0 0.80000000000000004em 1.3999999999999999em
}

div.tleft {
  float : left;
  clear : left;
  margin-right : 0.5em;
  border-width : 0.5em 1.3999999999999999em 0.80000000000000004em 0
}

img.thumbborder {
  border : 1px solid #dddddd
}

.hiddenStructure {
  display : none
}

table.rimage {
  float : right;
  position : relative;
  margin-left : 1em;
  margin-bottom : 1em;
  text-align : center
}

.toccolours {
  border : 1px solid #aaa;
  background-color : #f9f9f9;
  padding : 5px;
  font-size : 95%
}

.special li {
  line-height : 1.3999999999999999em;
  margin : 0;
  padding : 0
}

.rtl#bodyContent a.external {
  background-position : left;
  padding-right : 0
}

.rtl a.feedlink {
  background-position : right;
  padding-right : 16px;
  padding-left : 0
}

.ltr#bodyContent a.external {
  padding-left : 0
}

#bodyContent a.extiw, #bodyContent a.extiw:active {
  color : #36b
}

#bodyContent a.external {
  color : #36b
}

.portlet {
  border : none;
  margin : 0 0 0.5em;
  padding : 0;
  float : none;
  width : 11.6em;
  overflow : hidden
}

.portlet h4 {
  font-size : 95%;
  font-weight : normal;
  white-space : nowrap
}

.portlet h5 {
  background : transparent;
  padding : 0 1em 0 0.5em;
  display : inline;
  height : 1em;
  text-transform : lowercase;
  font-size : 91%;
  font-weight : normal;
  white-space : nowrap
}

.portlet h6 {
  background : #ffae2e;
  border : 1px solid #2f6fab;
  border-style : solid solid none solid;
  padding : 0 1em 0 1em;
  text-transform : lowercase;
  display : block;
  font-size : 1em;
  height : 1.2em;
  font-weight : normal;
  white-space : nowrap
}

.pBody {
  font-size : 95%;
  background-color : white;
  color : black;
  border-collapse : collapse;
  border : 1px solid #aaa;
  padding : 0 0.80000000000000004em 0.29999999999999999em 0.5em
}

.portlet h1, .portlet h2, .portlet h3, .portlet h4 {
  margin : 0;
  padding : 0
}

.portlet ul {
  line-height : 1.5em;
  list-style-type : square;
  list-style-image : url(bullet.gif);
  font-size : 95%
}

.portlet li {
  padding : 0;
  margin : 0
}

#p-logo {
  top : 0;
  left : 0;
  position : absolute;
  z-index : 3;
  height : 155px;
  width : 12em;
  overflow : visible
}

#p-logo h5 {
  display : none
}

#p-logo a, #p-logo a:hover {
  display : block;
  height : 155px;
  width : 12.199999999999999em;
  background-repeat : no-repeat;
  background-position : 35% 50% !important;
  text-decoration : none
}

#p-search {
  position : relative;
  z-index : 3
}

input.searchButton {
  margin-top : 1px;
  font-size : 95%
}

#searchGoButton {
  padding-left : 0.5em;
  padding-right : 0.5em;
  font-weight : bold
}

#searchInput {
  width : 10.9em;
  margin : 0;
  font-size : 95%
}

#p-search.pBody {
  padding : 0.5em 0.40000000000000002em 0.40000000000000002em 0.40000000000000002em;
  text-align : center
}

#p-search#searchform div div {
  margin-top : 0.40000000000000002em;
  font-size : 95%
}

#p-personal {
  position : absolute;
  left : 0;
  top : 0;
  z-index : 0
}

#p-personal {
  width : 100%;
  white-space : nowrap;
  padding : 0;
  margin : 0;
  border : none;
  background : none;
  overflow : visible;
  line-height : 1.2em
}

#p-personal h5 {
  display : none
}

#p-personal.portlet, #p-personal.pBody {
  z-index : 0;
  padding : 0;
  margin : 0;
  border : none;
  overflow : visible;
  background : none
}

#p-personal ul {
  border : none;
  line-height : 1.3999999999999999em;
  color : #2f6fab;
  padding : 0 2em 0 3em;
  margin : 0;
  text-align : right;
  list-style : none;
  z-index : 0;
  background : none;
  cursor : default
}

#p-personal li {
  z-index : 0;
  border : none;
  padding : 0;
  display : inline;
  color : #2f6fab;
  margin-left : 1em;
  line-height : 1.2em;
  background : none
}

#p-personal li a {
  text-decoration : none;
  color : #005896;
  padding-bottom : 0.20000000000000001em;
  background : none
}

#p-personal li a:hover {
  background-color : white;
  padding-bottom : 0.20000000000000001em;
  text-decoration : none
}

#p-personal li.active a:hover {
  background-color : transparent
}

li#pt-userpage, li#pt-anonuserpage, li#pt-login {
  background : url(user.gif) top left no-repeat;
  padding-left : 20px;
  text-transform : none
}

#p-personal ul {
  text-transform : lowercase
}

#p-personal li.active {
  font-weight : bold
}

#p-cactions {
  position : absolute;
  top : 1.3em;
  left : 11.5em;
  margin : 0;
  white-space : nowrap;
  width : 76%;
  line-height : 1.1000000000000001em;
  overflow : visible;
  background : none;
  border-collapse : collapse;
  padding-left : 1em;
  list-style : none;
  font-size : 95%
}

#p-cactions ul {
  list-style : none
}

#p-cactions li {
  display : inline;
  border : 1px solid #aaa;
  border-bottom : none;
  padding : 0 0 0.10000000000000001em 0;
  margin : 0 0.29999999999999999em 0 0;
  overflow : visible;
  background : white
}

#p-cactions li.selected {
  border-color : #fabd23;
  padding : 0 0 0.20000000000000001em 0;
  font-weight : bold
}

#p-cactions li a {
  background-color : #fbfbfb;
  color : #002bb8;
  border : none;
  padding : 0 0.80000000000000004em 0.29999999999999999em;
  position : relative;
  z-index : 0;
  margin : 0;
  text-decoration : none
}

#p-cactions li.selected a {
  z-index : 3;
  padding : 0 1em 0.20000000000000001em !important;
  background-color : white
}

#p-cactions.new a {
  color : #ba0000
}

#p-cactions li a:hover {
  z-index : 3;
  text-decoration : none;
  background-color : white
}

#p-cactions h5 {
  display : none
}

#p-cactions li.istalk {
  margin-right : 0
}

#p-cactions li.istalk a {
  padding-right : 0.5em
}

#p-cactions#ca-addsection a {
  padding-left : 0.40000000000000002em;
  padding-right : 0.40000000000000002em
}

li#ca-talk {
  margin-right : 1.6000000000000001em
}

li#ca-watch, li#ca-unwatch, li#ca-varlang-0, li#ca-print {
  margin-left : 1.6000000000000001em
}

#p-cactions.pBody {
  font-size : 1em;
  background-color : transparent;
  color : inherit;
  border-collapse : inherit;
  border : 0;
  padding : 0
}

#p-cactions.hiddenStructure {
  display : none
}

#p-cactions li a {
  text-transform : lowercase
}

#p-lang {
  position : relative;
  z-index : 3
}

.capitalize-all-nouns.portlet h5, .capitalize-all-nouns.portlet h6, .capitalize-all-nouns#p-personal ul, .capitalize-all-nouns#p-cactions ul li a {
  text-transform : none
}

#t-ispermalink, #t-iscite {
  color : #999
}

#footer {
  background-color : white;
  border-top : 1px solid #fabd23;
  border-bottom : 1px solid #fabd23;
  margin : 0.59999999999999998em 0 1em 0;
  padding : 0.40000000000000002em 0 1.2em 0;
  text-align : center;
  font-size : 90%
}

#footer li {
  display : inline;
  margin : 0 1.3em
}

#f-poweredbyico, #f-copyrightico {
  margin : 0 8px;
  position : relative;
  top : -2px
}

#f-poweredbyico {
  float : right;
  height : 1%
}

#f-copyrightico {
  float : left;
  height : 1%
}

.mw-htmlform-submit {
  font-weight : bold;
  padding-left : 0.29999999999999999em;
  padding-right : 0.29999999999999999em;
  margin-right : 2em
}

#preftoc {
  margin : 0;
  padding : 0;
  width : 100%;
  clear : both
}

#preftoc li {
  background-color : #f0f0f0;
  color : #000
}

#preftoc li {
  margin : 1px -2px 1px 2px;
  float : left;
  padding : 2px 0 3px 0;
  border : 1px solid #fff;
  border-right-color : #716f64;
  border-bottom : 0;
  position : relative;
  white-space : nowrap;
  list-style-type : none;
  list-style-image : none;
  z-index : 3
}

#preftoc li.selected {
  font-weight : bold;
  background-color : #f9f9f9;
  border : 1px solid #aaa;
  border-bottom : none;
  cursor : default;
  top : 1px;
  padding-top : 2px;
  margin-right : -3px
}

#preftoc>li.selected {
  top : 2px
}

#preftoc a, #preftoc a:active {
  display : block;
  color : #000;
  padding : 0 0.69999999999999996em;
  position : relative;
  text-decoration : none
}

#preftoc li.selected a {
  cursor : default;
  text-decoration : none
}

#preferences {
  margin : 0;
  border : 1px solid #aaa;
  clear : both;
  padding : 1.5em;
  background-color : #F9F9F9
}

.prefsection {
  border : none;
  padding : 0;
  margin : 0
}

.prefsection legend {
  font-weight : bold
}

.prefsection table, .prefsection legend {
  background-color : #F9F9F9
}

.mainLegend {
  display : none
}

td.htmlform-tip {
  font-size : x-small;
  padding : 0.20000000000000001em 2em;
  color : #666
}

.preferences-login {
  clear : both;
  margin-bottom : 1.5em
}

.prefcache {
  font-size : 90%;
  margin-top : 2em
}

div#userloginForm form, div#userlogin form#userlogin2 {
  margin : 0 3em 1em 0;
  border : 1px solid #aaa;
  clear : both;
  padding : 1.5em 2em;
  background-color : #f9f9f9;
  float : left
}

.rtl div#userloginForm form, .rtl div#userlogin form#userlogin2 {
  float : right
}

div#userloginForm table, div#userlogin form#userlogin2 table {
  background-color : #f9f9f9
}

div#userloginForm h2, div#userlogin form#userlogin2 h2 {
  padding-top : 0
}

div#userlogin.captcha, div#userloginForm.captcha {
  border : 1px solid #bbb;
  padding : 1.5em 2em;
  background-color : white
}

#loginend, #signupend {
  clear : both
}

#userloginprompt, #languagelinks {
  font-size : 85%
}

#login-sectiontip {
  font-size : 85%;
  line-height : 1.2;
  padding-top : 2em
}

#userlogin.loginText, #userlogin.loginPassword {
  width : 12em
}

#userloginlink a, #wpLoginattempt, #wpCreateaccount {
  font-weight : bold
}

*>html#p-cactions li {
  border : none
}

*>html#p-cactions li a {
  border : 1px solid #aaa;
  border-bottom : none
}

*>html#p-cactions li.selected a {
  border-color : #fabd23
}

*>html#f-poweredbyico, *>html#f-copyrightico {
  width : 88px
}

*>html#bodyContent, *>html#bodyContent pre {
  overflow-x : auto;
  width : 100%;
  padding-bottom : 25px
}

* html#footer {
  margin-top : 0
}

* html#column-content {
  display : inline;
  margin-bottom : 0
}

* html div.editsection {
  font-size : smaller
}

#pagehistory li.selected {
  position : relative
}

*>html#column-content {
  float : none
}

*>html#column-one {
  position : absolute;
  left : 0;
  top : 0
}

*>html#footer {
  margin-left : 13.199999999999999em
}

.redirectText {
  font-size : 150%;
  margin : 5px
}

.printfooter {
  display : none
}

div.patrollink {
  clear : both
}

.sharedUploadNotice {
  font-style : italic
}

span.updatedmarker {
  color : black;
  background-color : #0f0
}

.previewnote {
  color : #c00;
  margin-bottom : 1em
}

.previewnote p {
  text-indent : 3em;
  margin : 0.80000000000000004em 0
}

.editExternally {
  border : 1px solid gray;
  background-color : #ffffff;
  padding : 3px;
  margin-top : 0.5em;
  float : left;
  font-size : small;
  text-align : center
}

.editExternallyHelp {
  font-style : italic;
  color : gray
}

.toggle {
  margin-left : 2em;
  text-indent : -2em
}

input#wpSummary {
  width : 80%
}

input#wpSave, input#wpDiff {
  margin-right : 0.33000000000000002em
}

#wpSave {
  font-weight : bold
}

table.revisionform_default {
  border : 1px solid #000000
}

table.revisionform_focus {
  border : 1px solid #000000;
  background-color : #00BBFF
}

tr.revision_tr_default {
  background-color : #EEEEEE
}

tr.revision_tr_first {
  background-color : #DDDDDD
}

p.revision_saved {
  color : green;
  font-weight : bold
}

div.noarticletext {
  border : 1px solid #ccc;
  background : #fff;
  padding : 0.20000000000000001em 1em;
  color : #000
}

div#searchTargetContainer {
  left : 10px;
  top : 10px;
  width : 90%;
  background : white
}

div#searchTarget {
  padding : 3px;
  margin : 5px;
  background : #F0F0F0;
  border : solid 1px blue
}

div#searchTarget ul li {
  list-style : none
}

div#searchTarget ul li:before {
  color : orange;
  content : "» "
}

div#searchTargetHide {
  float : right;
  border : solid 1px black;
  background : #DCDCDC;
  padding : 2px
}

#powersearch p {
  margin-top : 0px
}

div.multipageimagenavbox {
  border : solid 1px silver;
  padding : 4px;
  margin : 1em;
  background : #f0f0f0
}

div.multipageimagenavbox div.thumb {
  border : none;
  margin-left : 2em;
  margin-right : 2em
}

div.multipageimagenavbox hr {
  margin : 6px
}

table.multipageimage td {
  text-align : center
}

.templatesUsed {
  margin-top : 1.5em
}

.mw-summary-preview {
  margin : 0.10000000000000001em 0
}

div.mw-lag-warn-normal, div.mw-lag-warn-high {
  padding : 3px;
  text-align : center;
  margin : 3px auto
}

div.mw-lag-warn-normal {
  border : 1px solid #FFCC66;
  background-color : #FFFFCC
}

div.mw-lag-warn-high {
  font-weight : bold;
  border : 2px solid #FF0033;
  background-color : #FFCCCC
}

.MediaTransformError {
  background-color : #ccc;
  padding : 0.10000000000000001em
}

.MediaTransformError td {
  text-align : center;
  vertical-align : middle;
  font-size : 90%
}

.os-suggest {
  font-size : 127%
}

.no-text-transform {
  text-transform : none
}