/*   
Theme Name:jQ
Theme URI:http://devolux.org/jq
Description:WordPress theme with two columns, four widget areas and loads of jQuery functions (dropdown navigation, font resizing and more). The theme options include a movable sidebar, custom colours, excerpts on index pages, category or page navigation, different font and colour schemes. 
Author:Devolux
Author URI:http://devolux.org/
Version:2.4
Tags:two-columns, fixed-width, theme-options, custom-colors, blue, green, dark
.
Released under the <a href="http://www.opensource.org/licenses/gpl-license.php">GPL</a>.
.
*/

/*       ###############################
         BASIC TAGS
         ############################### */

* {margin:0; padding:0;}
body {font:normal 10px Helvetica; color:#666; background:url(img/bg-blue.jpg) top center no-repeat #193c74;}
h1, h2, h3, h4, h5, h6 {margin:10px 0 0 0;}
p {margin:0px 0px 20px 0px;}
a {outline:none; text-decoration:none; color:#8a8a8a;}
a:hover {color:#215c97;}
a img {border:none;}

/*       ###############################
         BASIC LAYOUT
         ############################### */

div#outline {width:960px; margin:0 auto;}

div#nav {position:relative; z-index:2; width:960px; height:38px; background:url(img/nav.png);}
div#content {clear:both; z-index:1; background:#fff; width:880px; padding:10px 40px 0 40px;}

div#left {width:560px; margin:0; line-height:2.0; float:left; padding:0 20px 10px 0;}
div#right {width:240px; margin:0; float:right; padding:10px 0 10px 20px;}

p#toggle-all {float:right; width:100px; margin:0; padding:0;}

div.headline {margin:40px 0 0 20px;}
div.excerpt {padding:0 0 5px 0; border-bottom:dotted 1px #ccc; margin:0 0 0 20px;}
div.post-single {margin:0 0 20px 0;}

div.preview {float:right; background:url(img/preview.png) no-repeat; margin:15px 0 0 0;}
div.preview a {display:block; width:20px; height:20px; color:#ccc !important; font:normal 14px Verdana, serif;}

div.date {position:absolute; width:60px; height:60px; padding:10px 0; margin:0 0 0 -80px; background:#fff; -moz-border-radius:5px;-webkit-border-radius: 5px;}

div.single_content {clear:both; margin:0 0 50px 0px;}
div.bookmarks {text-align:right; float:right;}

div#appendix {clear:both; background:#fff; width:930px; padding:30px 30px 30px 0px; margin:0 0 50px 0;}
div.app_widget {float:left; width:280px; padding:0px 0px 0px 30px;}
div#appendix div.widget {padding:20px 0 0 0;}

/*       ###############################
         NAVIGATION
         ############################### */

div#nav ul {float:left; list-style:none;}

div#nav li {float:left;}
div#nav li a {display:block; margin:0; padding:11px 16px 10px 16px; color:#f5f5f5; text-decoration:none; font:bold 12px Helvetica, sans-serif; border-left:1px solid #222;}
div#nav li a:hover {background:#111; color:#215c97;}

ul#mail_rss a {text-decoration:underline !important;}

/*       ###############################
         WIDGETS
         ############################### */

.widget {border:1px solid #ccc; padding:25px 15px !important; margin:10px 0; -moz-border-radius:5px;-webkit-border-radius: 5px;}
div.widget h4 {border-bottom:1px dotted #ccc; font:bold 120% Helvetica, sans-serif;}

div#right, div#appendix {font-size:120%;}
div#right ul, div#appendix ul {list-style:none; padding:0;}

div.widget h4 {font-size:130%; margin:0; padding:0 0 3px 0;}
div.widget a {display:block; padding:5px 0px; font:normal 110% Helvetica, sans-serif; color:#215c97;}
div.widget a:hover {color:#666; text-decoration:underline;}
div.widget li {padding:0 0 0 5px; margin:0; border-bottom:1px dotted #ccc;}
div.widget li li {padding:0 0 0 20px; margin:0; background:none; border-top:none; border-bottom:none;}

div#tag_cloud a {display:inline;}
div#tag_cloud {min-height:130px;}
div#archives {min-height:130px;}

.textwidget, .textwidget a {font: italic 120% Georgia, serif !important;}
.textwidget p {margin: 0; padding: 0;}

/*calendar*/
table#wp-calendar {margin:0 0 10px 0; border-collapse:collapse; text-align:center; font-size:14px;}
table#wp-calendar a {font:normal 14px Verdana;}
table#wp-calendar caption {padding:0 0 5px 0;}
table#wp-calendar th {font:bold 14px Verdana;}
table#wp-calendar th, td {width:30px; height:30px;}

/*       ###############################
         TEXT
         ############################### */

div#blog-line h1 a {font:normal 60px Georgia, serif; color:#fff;}
div#blog-line h1 {font:40px Georgia, serif; padding:20px 0; margin:0; color:#fff; letter-spacing:-2px;}

div#left {font-size:120%;}
div#left a {color:#215c97;}
div#left a:hover {color:#ccc; text-decoration:underline;}
div#left h1 {float:left; font:bold 26px Helvetica, sans-serif; width:450px; letter-spacing:-1px;}
div#left h1.page_headline {margin:10px 0; font:bold 26px Helvetica, sans-serif; color:#215c97;}
div#left h1 a {color:#666; display:block;}
div#left h1 a:hover {color:#215c97; text-decoration:none;}
div#left h2 {font:bold 150% Georgia, serif; margin:0 0 10px 0;}
div#left h2.archive-title {margin:10px 0 0 20px; font:bold 26px Helvetica, sans-serif; color:#215c97;}
div#left h3 {font:italic 120% Georgia, serif; margin:0 0 5px 0;}
div#left ul, ol {margin:0 0 20px 20px;}

div.excerpt {font-size:120%;}
div.single_content {font-size:120%;}

p#font-resize a {display:inline; font:18px bold Verdana, sans-serif; padding:0px 5px;}
p#toggle-all a {display:block; width:80px; height:20px; padding:0 0 0 30px !important; font:12px bold Verdana, sans-serif;}
a.show-all {background:url(img/toggle.png) no-repeat;}
a.hide-all {background:url(img/toggle.png) 0px -20px no-repeat;}

p.previous-posts {margin:50px 0 0 0; float:left; font:normal 130% Verdana;}
p.next-posts {margin:50px 0 0 0; float:right; font:normal 130% Verdana;}
div.date {font:normal 14px Georgia; text-align:center; color:#666;}
p.date-month {margin:2px 0 15px 0; color:#999; font:normal 32px Georgia;}

p.post_info {font-size:100%;}
p.tag_info {margin:0; font-size:100%;}
p.offset {margin:5px 0;}

p.wp-bookmark {margin:0;}
.wp-logo {float:left;}
div#credits {margin:0 0 0 65px; padding:5px 10px; height:46px; border:1px solid #ccc; -moz-border-radius:10px;-webkit-border-radius: 10px; font:120% normal Georgia, serif;}
a#totop {float:right; font:bold 120% Verdana, sans-serif;}

.category-link {background:url(img/page.png) no-repeat;}
.comment-link {background:url(img/comments.png) no-repeat;}
.tag-link {background:url(img/tag-blue.png) no-repeat;}
.hide-link {float:right; padding:8px 0 0 0; font: normal 12px Helvetica, sans-serif;}
.user-name {background:url(img/user-green.png) no-repeat;}
.user-mail {background:url(img/email.png) no-repeat;}
.user-url {background:url(img/world-edit.png) no-repeat;}
.user-comment {background:url(img/comment-add.png) no-repeat;}
.info-icon {padding:3px 0 3px 20px; margin:0; background-position:0px 4px;}
 
.clear {clear:both;}

code {font:normal 120% Courier, serif;}

/*      ##################################
           COMMENTS
        ################################## */

div.comment {margin:10px 0 30px 0; padding:10px 0; border-bottom:1px dotted #ccc;}
p.comment-details {font:normal 130% Georgia, serif;}
.avatar {float:left; margin:0 20px 0 0; border:5px solid #eee;-moz-border-radius:5px;-webkit-border-radius: 5px;}
div.comment-text {margin:50px 0 0 0;}
div.author-comment {background: #f9fbc1;-moz-border-radius:5px;-webkit-border-radius:5px; padding: 10px !important; border:1px solid #f1f1f1;}

h2#comment-header {margin:40px 0 10px 0 !important; border-bottom:1px dotted #ccc; padding:0 0 5px 0;}
h2#respond {margin:40px 0 10px 0 !important;}
h3#no-comments {font:italic bold 110% Georgia, serif !important; color:#666 !important;}

/*        ##################################
           FORMS
        ################################## */

label {display:block; margin:0 0 5px 0;}
.text {width:350px; margin:0 0 10px 0; padding:5px; background:url(img/bg-form-text.gif) repeat-x left top #fff; border:1px solid #ccc;}
textarea {width:450px; height:150px; margin:0; padding:5px; background:url(img/bg-form-text.gif) repeat-x left top #fff; border:1px solid #ccc; -moz-border-radius:5px;}
.submit {width:auto; padding:5px 20px; margin:5px 0; color:#fff; background:#333; border:1px solid #333; -moz-border-radius:5px;-webkit-border-radius: 5px;}
input {-moz-border-radius:5px;-webkit-border-radius: 5px; margin:0 5px 0 0;}

/*        ##################################
           SEARCHFORM
        ################################## */

input#search {width:150px; padding:5px; background:url(img/bg-form-text.gif) repeat-x left top; border:1px solid #ccc;}
#search-submit {padding:5px; color:#fff; background:#333; border:none;}
div#left div#searchform {padding: 0 0 0 20px;}
p.not-found {padding: 0 0 0 20px; margin:0;}

/*        ##################################
           WORDPRESS CSS
        ################################## */

img.alignright {float:right; margin:0 0 30px 30px;}
img.alignleft {float:left; margin:0 50px 30px 0;}
img.aligncenter {display:block; margin-left:auto; margin-right:auto;}
a img.alignright {float:right; margin:0 0 30px 30px;}
a img.alignleft {float:left; margin:0 50px 30px 0;}
a img.aligncenter {display:block; margin-left:auto; margin-right:auto;}

.aligncenter, div.aligncenter {display:block; margin-left:auto; margin-right:auto;}
.alignleft {float:left;}
.alignright {float:right;}

.wp-caption {border:1px solid #ddd; text-align:center; background-color:#f3f3f3; padding-top:4px; margin:10px;}
.wp-caption img {margin:0;padding:0;border:0 none;}
.wp-caption p.wp-caption-text {font-size:110%; line-height:17px; padding:0 4px 5px; margin:0;}

/*        ##################################
           SUPERFISH
        ################################## */

/*** ESSENTIAL STYLES ***/
.sf-menu, .sf-menu * {margin:0;padding:0;list-style:none;}
.sf-menu {line-height:1.0;}
.sf-menu ul {position:absolute;top:-999em;width:10em; /* left offset of submenus need to match (see below) */}
.sf-menu ul li {width:100%;margin:0 !important;}
.sf-menu ul ul li{margin:0 !important;}
.sf-menu li:hover {visibility:inherit; /* fixes IE7 'sticky bug' */}
.sf-menu li {float:left;position:relative;}
.sf-menu a {display:block;position:relative;}
.sf-menu li:hover ul,.sf-menu li.sfHover ul {left:0;top:38px; /* match top ul list item height */ z-index:1000;}
ul.sf-menu li:hover li ul, ul.sf-menu li.sfHover li ul {top:-999em;}
ul.sf-menu li li:hover ul, ul.sf-menu li li.sfHover ul {left:10em; /* match ul width */ top:0;}
ul.sf-menu li li:hover li ul, ul.sf-menu li li.sfHover li ul {top:-999em;}
ul.sf-menu li li li:hover ul, ul.sf-menu li li li.sfHover ul {left:10em; /* match ul width */ top:0;}

/*** CUSTOM STYLES ***/
.sf-menu li ul {background:#222;border:1px solid #000;border-top:none;opacity:0.9;-moz-opacity:0.9;filter:alpha(opacity=90);}
.sf-menu li li ul, .sf-menu li li li ul {background:#222;border:1px solid #000;border-top:none;opacity:1.0;-moz-opacity:1.0;filter:alpha(opacity=100);}

/*       ###############################
         CLEARFIX
         ############################### */

.clearfix:after {content:"."; display:block; clear:both; visibility:hidden; line-height:0; height:0;}
.clearfix {display:inline-block;}
html[xmlns] .clearfix {display:block;}
* html .clearfix {height:1%;}
.clear {clear:both;}
